# Matcha Matching Game

This is a simple matching game implemented in Python.

## How to Play

1. Run the `matcha_game.py` script.
2. Enter the coordinates of two symbols on the board to reveal them.
3. If the symbols match, you score a point!
4. Keep revealing symbols and matching them until all pairs are found.

Have fun!
